@@ -1081,11 +1081,13 @@ static int do_resolve_tree(resolver_state *rs, tree_walk *tw)
 					{
 						char recv[INET6_ADDRSTRLEN];
 						do_report(LOG_NOTICE,
-							"DNS: timeout server[%d]: %s",
+							"DNS: timeout server[%d]: %s ("
+							"got %d/%d responses for %s)",
 							rs->cur_ns,
 							inet_ntop(rs->servers[rs->cur_ns].ip == 4? AF_INET: AF_INET6,
 								rs->servers[rs->cur_ns].u.ip_data,
-								recv, sizeof recv));
+								recv, sizeof recv),
+							tot_recv, ndom, tw->dd[0].domain);
 					}
 					break;
 				}
@@ -1705,7 +1707,7 @@ is_relaxed_aligned(resolver_state *rs, tree_walk *tw, char const *domain)
 	return rtc;
 }
 
-static int is_subdomain(char const *domain, char const *org_domain)
+int is_subdomain(char const *domain, char const *org_domain)
 {
 	if (!domain || !org_domain)
 		return 0;
@@ -1713,7 +1715,7 @@ static int is_subdomain(char const *domain, char const *org_domain)
 	unsigned dlen = strlen(domain);
 	unsigned olen = strlen(org_domain);
 
-	return dlen > olen && strincmp(domain + dlen - olen, org_domain, olen) == 0;
+	return dlen >= olen && strincmp(domain + dlen - olen, org_domain, olen) == 0;
 }
 
 int
